@@ -1,9 +1,12 @@
 use anyhow::anyhow;
 use std::fmt::{Debug, Formatter, Display};
+use std::str::Utf8Error;
+use dochy_archiver2::NouArcError;
 
 pub type CoreResult<T> = std::result::Result<T, CoreError>;
 
 
+
 pub struct CoreError {
     e : anyhow::Error,
 }
@@ -50,8 +53,17 @@ impl From<&str> for CoreError {
     }
 }
 
+impl From<Utf8Error> for CoreError{
+    fn from(e : Utf8Error) -> Self{ Self::new(e) }
+}
+
+impl From<NouArcError> for CoreError{
+    fn from(e : NouArcError) -> Self{ Self::new(e) }
+}
+
 impl Into<anyhow::Error> for CoreError {
     fn into(self) -> anyhow::Error {
         self.e
     }
-}
\ No newline at end of file
+}
+
