@@ -1,7 +1,10 @@
 use std::collections::HashMap;
 use std::hash::{Hash, BuildHasher};
 use crate::imp::structs::linked_m::LinkedMap;
+use std::sync::Arc;
 
+/// When items have identity objects, compare identity objects, otherwise compare items directly.
+/// This can shortcut comparing and make it faster.
 pub trait IdentityEqual{
     fn identity_eq(&self, other : &Self) -> bool;
 }
@@ -19,6 +22,13 @@ impl<K,  V : IdentityEqual, S> IdentityEqual for HashMap<K,V,S>
     }
 }
 
+impl<T : IdentityEqual> IdentityEqual for Arc<T>{
+    fn identity_eq(&self, other: &Self) -> bool {
+        if Arc::ptr_eq(self, other){ true }
+        else{ self.as_ref().identity_eq(other.as_ref())}
+    }
+}
+
 impl IdentityEqual for bool{
     fn identity_eq(&self, other: &Self) -> bool {
         self == other
